/**
 * Copyright Damiano Bolla, Cologna Veneta, Italy, All right reserved
 * Eclipse does not have any more copyright manager, so I need to edit by hand
 * GNU LESSER GENERAL PUBLIC LICENSE Version 3, 29 June 2007
 */

#include <ipps_utils.h>
#include <fcntl.h>

/**
 * this receives a line where there is a row and a mask and will apply using the given debugger
 * if row_idx is ZERO then the debug mask is set for the static stat object
 */
void console_set_row_debug ( char *row_mask, IppsuInt32ProwFun debugGet )
   {
   if ( ! row_mask ) return;

   if ( ! debugGet ) return;

   int idx;
   int mask;

   if ( sscanf(row_mask,"%i %x",&idx, &mask) != 2)
      {
      CONSOLE_PRINTF("console_set_row_debug: missing index or mask\n");
      return;
      }

   uint32 *debugP = (*debugGet)(idx);
   if ( ! debugP )
      {
      CONSOLE_PRINTF("console_set_debugm: BAD index %d\n",idx);
      return;
      }

   *debugP=mask;

   CONSOLE_PRINTF("console_set_row_debug [%d] mask 0x%x\n",idx, mask);
   }

/**
 * get a random salt of given len
 * The salt will be terminated by a leading zero
 */
void unix_random_get_bytes (void * const vtoP, uint16 const to_len)
   {
   int random_fd = open("/dev/urandom", 0);
   if ( random_fd < 0 )
      {
      CONSOLE_PRINTF("open /dev/urandom FAILED");
      time_t now=time(NULL);
      // this is better than nothing
      memcpy(vtoP,&now,to_len);
      return;
      }

   int have;
   if ( (have=read(random_fd,vtoP,to_len)) != to_len )
      CONSOLE_PRINTF("unix_random_get_bytes: wanted=%d have=%d\n",to_len,have);

   close (random_fd);
   }
