/**
 * Copyright Damiano Bolla, Cologna Veneta, Italy, All right reserved
 * Eclipse does not have any more copyright manager, so I need to edit by hand
 * GNU LESSER GENERAL PUBLIC LICENSE Version 3, 29 June 2007
 */

#include <strtoksep.h>


/**
 * This split the given string starting from StartP splitting separator ONLY
 * the normal strtok gives unwanted result when two tabs are one after the other
 * @param ch_sep the single ch separator to look out for, MUST be non zero
 */
char *strtok_sep ( char *beginP, char **startPP, uint8 ch_sep )
   {
   if ( startPP == NULL ) return NULL;

   // if the beginning pointer is set then the start becomes the beginning
   if ( beginP ) *startPP = beginP;

   // now, back to normal flow, the start of string is normally this
   // save it away for later use
   char *startP = *startPP;

   // normal parsing begins at start
   char *curP = startP;

   if ( curP == NULL ) return NULL;

   uint8 curch = *curP;

   if ( curch == 0 )
      {
      // basically we are at the end of the parsing string, there is nothing to return
      *startPP = NULL;
      return NULL;
      }

   if ( curch == ch_sep )
      {
      // the first char is a tab
      *curP = 0;  // zero the tab
      *startPP = startP+1;  // next starting point will be one over
      return startP;  // but return this starting point so I can find an empty string
      }

   // now I need to find a zero or a tab
   while ( (curch = *curP), curch && curch != ch_sep ) curP++;

   if ( curch == 0 )
      {
      // I am at the end of parsing string, so, next start is null
      *startPP = NULL;
      }
   else if ( curch == ch_sep )
      {
      // the char I have found is a tab
      *curP = 0;  // zero the tab
      *startPP = curP + 1;  // next starting point will be one over the tab I just zeroed
      }

   return startP;
   }


char *strtok_tab ( char *beginP, char **startPP )
   {
   return strtok_sep (beginP, startPP, '\t' );
   }
